@@ -4,49 +4,69 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "0.05";
+    $VERSION = "0.06";
 }
 
 use Acme::CPANAuthors::Register (
+    AALLAN      => 'Alasdair Allan',
     ABURLISON   => 'Alan Burlison',
     ABW         => 'Andy Wardley',
+    ACMCMEN     => 'Adrian McMenamin',
+    ADAMGENT    => 'Adam Gent',
     ADDW        => 'Alain Williams',
     ADIE        => 'Adrian Howard',
+    ADYE        => 'Tim Adye',
+    ADZZ        => 'Adam Griffiths',
     AECOOPER    => 'Anthony Edward Cooper',
+    AFINDLAY    => 'Andrew Findlay',
     AGIERTH     => 'Andrew P. J. Gierth',
     AHORNBY     => 'Alex Hornby',
     AJFRY       => 'Alan J. Fry',
     AJGOUGH     => 'Alex Gough',
+    AJPEACOCK   => 'Anthony Peacock',
     ALANC       => 'Alan Champion',
     ALEXF       => 'Alex Francis',
     ALEXMC      => 'Alex McLintock',
     ALPOW       => 'Alan Pownall',
+    AMIAS       => 'Amias Channer',
     ANDREWF     => 'Andrew Ford',
     ANDREWS     => 'Andrew Stringer',
     ANDYA       => 'Andy Armstrong',
+    ANDYW       => 'Andy Walker',
     ANWILL      => 'Andy Williams',
     ARC         => 'Aaron Crane',
+    ARJONES     => 'Andrew Jones',
+    ARTICLE     => 'Andrew Green',
     ASH         => 'Ash Berlin',
     ASPIERS     => 'Adam Spiers',
     ATRICKETT   => 'Adam John Trickett',
+    AWRIGLEY    => 'Ave Wrigley',
     BADGERSRC   => 'Mark Clements',
     BARBIE      => 'Barbie',
+    BELCHAM     => 'Craig R. Belcham',
     BEN         => 'Ben Laurie',
+    BENLUND     => 'Ben Lund',
+    BENTIS      => 'Ben Tisdall',
+    BEVANS      => 'Ben Evans',
     BIGPRESH    => 'David Precious',
     BINGOS      => 'Chris Williams',
+    BIRNEY      => 'Ewan Birney',
     BISSCUITT   => 'Ian Bissett',
     BMORROW     => 'Ben Morrow',
     BOBNET      => 'Robert Cornell',
     BOBTFISH    => 'Tomas Doran',
     BOBW        => 'Bob Wilkinson',
+    BURKEY      => 'Daniel Burke',
     CAILLTE     => 'Simon Parsons',
     CCOLBOURN   => 'Charles Colbourn',
     CDOT        => 'Crawford Currie',
     CHISEL      => 'Chisel Wright',
     CHSTROSS    => 'Charlie Stross',
     CJK         => "Christopher Key",
+    CJONES      => 'Christopher Jones',
     CLIFFORDJ   => 'Jason Clifford',
     COLINFINE   => 'Colin Fine',
+    COPPERLY    => 'Copperly Ltd.',
     COSMICNET   => 'Lyle Hopkins',
     COWFISH     => 'Billy Abbott',
     CPWILLMOT   => 'Christopher Willmot',
@@ -56,22 +76,28 @@ use Acme::CPANAuthors::Register (
     DAVEHODG    => 'Dave Hodgkinson',
     DAVIDHJ     => 'David Hugh-Jones',
     DCANTRELL   => 'David Cantrell',
+    DENNEY      => 'Chris Denney',
+    DETOX       => 'Jonathan Waller',
     DGL         => 'David Leadbeater',
     DHICKLING   => 'Dave Hickling',
     DIOCLES     => 'Tim Retout',
     DIVEC       => 'David Chan',
+    DJK         => 'Dirk-Jan Koopman',
     DOM         => 'Dominic Hargreaves',
     DORWARD     => 'David Dorward',
     DRAXIL      => 'Joe Higton',
+    DREWF       => 'Andy Ferguson',
     DUFFEE      => 'Boyd Duffee',
     DVSM        => 'Stuart Butler',
     DWILSON     => 'Dean Wilson',
     EFIFER      => 'Eric Fifer',
+    EGYPTUS     => 'Nick Humphries',
     ELLIOTT     => 'Simon Elliott',
     ELPENGUIN   => 'James Laver',
     EMARTIN     => 'Earle Martin',
     EVDB        => 'Edmund von der Burg',
     EXOBUZZ     => 'Jools Wills',
+    GDR         => 'Gareth D. Rees',
     GHENRY      => 'Gavin Henry',
     GLENSMALL   => 'Glen Small',
     GMCCAR      => 'Greg McCarroll',
@@ -79,14 +105,17 @@ use Acme::CPANAuthors::Register (
     HDM         => 'Dominic Mitchell',
     HEX         => 'Earle Martin',
     HITHERTO    => 'Simon Batistoni',
+    HOGGARTH    => 'Neil Hoggarth',
     HVDS        => 'Hugo van der Sanden',
     IAINT       => 'Iain Tatch',
     ICLARK      => 'Ian Clark',
     IDORU       => 'Russell Matbouli',
+    ISTEEL      => 'Ian Steel',
     ITDEV       => 'Bruce Mitchell',
     JABLKO      => 'Jack Bates',
     JAGS        => 'Jagdeep S. Sandhu',
     JAMESPO     => 'James Powell',
+    JAMESR      => 'James Ronan',
     JARLE       => 'Jarle Brinchmann',
     JARW        => 'John A.R. Williams',
     JCTEBBAL    => 'Jean-Claude Tebbal',
@@ -115,6 +144,7 @@ use Acme::CPANAuthors::Register (
     LGODDARD    => 'Lee Goddard',
     LILSTEVEY   => 'Steven Pitchford',
     LLAP        => 'Leo Lapworth',
+    LLOYDG      => 'Lloyd Griffiths',
     LMJM        => 'Lee McLoughlin',
     LORDO       => 'Lawrence Tierney',
     MACDEE      => 'Craig Macdonald',
@@ -126,6 +156,7 @@ use Acme::CPANAuthors::Register (
     MARTINTO    => 'Martin Tomes',
     MATTBM      => 'Matthew Byng-Maddick',
     MAVIT       => 'Peter Oliver',
+    MCB         => 'Michael Brown',
     MCNEWTON    => 'Matthew C. Newton',
     MEH         => 'Andy Smith',
     MFENTON     => 'Mathew Fenton',
@@ -134,6 +165,7 @@ use Acme::CPANAuthors::Register (
     MIKEJ       => 'Mike Jones',
     MIRK        => 'Mike Taylor',
     MJBRIGHT    => 'Martin Bright',
+    MJEWELL     => 'Mike Jewell',
     MJG         => 'Michael Gray',
     MJM         => 'Matt Mitchell',
     MJS         => 'Michael Smith',
@@ -152,6 +184,7 @@ use Acme::CPANAuthors::Register (
     MWARD       => 'Martin Ward',
     MWILSON     => 'Matt Wilson',
     NATHANL     => 'Nathan Lewis',
+    NHORNE      => 'Nigel Horne',
     NIGE        => 'Nigel Hamilton',
     NIGELM      => 'Nigel Metheringham',
     NIKC        => 'Nik Clayton',
@@ -202,6 +235,7 @@ use Acme::CPANAuthors::Register (
     SAM         => 'Simon Matthews',
     SARGIE      => 'Peter Sergeant',
     SCHUBOE     => 'Benjamin Schuster-Bockler',
+    SDPRICE     => 'Steve Price',
     SEB         => 'Steven Brenner',
     SENDU       => 'Sendu Bala',
     SHERWOOD    => 'Steve Sherwood',
